/*
 * [XenuPrep.java]
 *
 * Summary: Tidy a piece of a xenu.ini file, tidying up a previous attempt.
 *
 * Copyright: (c) 2015-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2015-12-28 initial version
 */
package com.mindprod.ini;

import com.mindprod.common18.EIO;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;

import static java.lang.System.*;

/**
 * Tidy a piece of a xenu.ini file, tidying up a previous attempt.
 * <p/>
 * It includes:
 * Enable1=1
 * Enable2=1
 * String1=file:///C:/Program Files (x86)/Java
 * String2=file:///C:/Program Files/Java
 * Strings are sorted, deduped and renumbered
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2015-12-28 initial version
 * @since 2015-12-28
 */
public final class XenuPrep
    {
    /**
     * true if want extra debugging output
     */
    private static final boolean DEBUGGING = false;

    private static final int FIRST_COPYRIGHT_YEAR = 2015;

    /**
     * undisplayed copyright notice
     */
    private static final String EMBEDDED_COPYRIGHT =
            "Copyright: (c) 2015-2017 Roedy Green, Canadian Mind Products, http://mindprod.com";

    private static final String RELEASE_DATE = "2015-12-27";

    /**
     * embedded version string.
     */
    private static final String VERSION_STRING = "1.0";

    private static final ArrayList<String> urls = new ArrayList<>( 1000 );

    private static PrintWriter p;

    private static ArrayList<String> deduped;

    private static void dedup()
        {
        deduped = new ArrayList<>( urls.size() );
        String prev = null;
        for ( String url : urls )
            {
            if ( url != prev )
                {
                prev = url;
                deduped.add( url );
                }
            else
                {
                out.println( "duplicate " + url + " dropped" );
                }
            }
        urls.clear();
        }

    private static void export() throws IOException
        {
        // write over top of input
        final PrintWriter p = EIO.getPrintWriter( new File( "xenu.inifrag" ), 64 * 1024, EIO.UTF8 );
        int n = deduped.size();
        for ( int i = 1; i <= n; i++ )
            {
            p.println( "Enable" + i + "=1" );
            }
        int j = 1;
        for ( String url : deduped )
            {
            p.println( "String" + j++ + "=" + url );
            }
        p.close();
        out.println( n + " deduped items processed." );
        }

    private static void readUrls() throws IOException
        {
        final BufferedReader r = EIO.getBufferedReader( new File( "xenu.inifrag" ), 64 * 1024, EIO.UTF8 );
        String line;
        while ( ( line = r.readLine() ) != null )
            {
            if ( line.startsWith( "Enable" ) )
                {
                continue;
                }
            int p = line.indexOf( '=' );
            if ( p < 0 )
                {
                continue;
                }
            urls.add( line.substring( p + 1 ) );
            }
        r.close();
        }

    /**
     * command line utility. Tidies a section of the xenu.ini file, not the whole thing.
     *
     * @param args not used
     */
    public static void main( final String[] args ) throws IOException
        {
        readUrls();
        // sort urls alphabetically.
        Collections.sort( urls );
        dedup();
        export();
        } // end main
    } // end XenuPrep
